@@ -13,23 +13,21 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import warnings
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
+import warnings
 
-from google.api_core import gapic_v1
-from google.api_core import grpc_helpers_async
+from google.api_core import gapic_v1, grpc_helpers_async
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-
-import grpc  # type: ignore
-from grpc.experimental import aio  # type: ignore
-
-from google.cloud.secretmanager_v1.types import resources
-from google.cloud.secretmanager_v1.types import service
 from google.iam.v1 import iam_policy_pb2  # type: ignore
 from google.iam.v1 import policy_pb2  # type: ignore
 from google.protobuf import empty_pb2  # type: ignore
-from .base import SecretManagerServiceTransport, DEFAULT_CLIENT_INFO
+import grpc  # type: ignore
+from grpc.experimental import aio  # type: ignore
+
+from google.cloud.secretmanager_v1.types import resources, service
+
+from .base import DEFAULT_CLIENT_INFO, SecretManagerServiceTransport
 from .grpc import SecretManagerServiceGrpcTransport
 
 
